package de.intevation.flys.artifacts.model.minfo;

import org.apache.log4j.Logger;

import de.intevation.artifactdatabase.state.Facet;
import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;
import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.model.CalculationResult;
import de.intevation.flys.artifacts.model.DataFacet;
import de.intevation.flys.artifacts.states.DefaultState.ComputeType;


/**
 * Facet for serving bed diameter data.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class BedDiameterFacet extends DataFacet {

    private static final long serialVersionUID = 1L;

    private static Logger logger = Logger.getLogger(BedDiameterFacet.class);

    public BedDiameterFacet() {
    }

    public BedDiameterFacet(int idx, String name, String description,
        ComputeType type, String stateId, String hash) {
        super(idx, name, description, type, hash, stateId);
    }

    public Object getData(Artifact artifact, CallContext context) {
        logger.debug("Get data for bed diameter at index: " + index);

        FLYSArtifact flys = (FLYSArtifact) artifact;

        CalculationResult res = (CalculationResult) flys.compute(context, hash,
            stateId, type, false);

        int ndx = index >> 8;
        Object[] data = ((BedQualityResult[]) res.getData())[ndx].getBedResults(); // TODO CAST TO SPECIFIC CLASS

        int ndy = index & 255;
        return data != null && data.length > ndy ? data[ndy] : null;
    }

    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        BedDiameterFacet copy = new BedDiameterFacet();
        copy.set(this);
        copy.type = type;
        copy.hash = hash;
        copy.stateId = stateId;
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
